==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/eo.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Interservila kunhavo ne kapabliĝis en ĉi tiu servilo",
    "Not allowed to create a federated share with the same user server" : "Ne kreeblas federa kunhavo per la sama uzantoservilo",
    "Invalid or untrusted SSL certificate" : "SSL-atestilo ne validas aŭ ne fidindas",
    "Storage not valid" : "Memoro ne validas",
    "Couldn't add remote share" : "Ne aldoneblas fora kunhavo",
    "Shared with you" : "Kunhavata kun vi",
    "Shared with others" : "Kunhavata kun aliaj",
    "Shared by link" : "Kunhavata per ligilo",
    "Uploading..." : "Alŝutante...",
    "Nothing shared with you yet" : "Nenio kunhavatas kun vi ankoraŭ",
    "Files and folders others share with you will show up here" : "Dosieroj kaj dosierujoj, kiujn aliuloj kunhavigas, aperos ĉi tie",
    "Nothing shared yet" : "Nenio kunhavatas ankoraŭ",
    "Files and folders you share will show up here" : "Dosieroj kaj dosierujoj, kiujn vi kunhavigas, aperos ĉi tie",
    "No shared links" : "Neniu kunhavata ligilo",
    "Files and folders you share by link will show up here" : "Dosieroj kaj dosierujoj, kiujn vi kunhavigas per ligilo, aperos ĉi tie",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ĉu vi volas aldoni la foran kunhavon {name} de {owner}@{remote}?",
    "Remote share" : "Fora kunhavo",
    "Remote share password" : "Pasvorto de fora kunhavo",
    "Cancel" : "Nuligi",
    "Add remote share" : "Aldoni foran kunhavon",
    "You can upload into this folder" : "Vi povas alŝuti en ĉi tiun dosierujon",
    "No ownCloud installation (7 or higher) found at {remote}" : "Ne troviĝis instalo de ownCloud (7 aŭ pli alta) ĉe {remote}",
    "Invalid ownCloud url" : "Nevalidas URL de ownCloud",
    "Share" : "Kunhavigi",
    "Shared by" : "Kunhavigita de",
    "Sharing" : "Kunhavigo",
    "A file or folder has been <strong>shared</strong>" : "Dosiero aŭ dosierujo <strong>kunhaviĝis</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Dosiero aŭ dosierujo kunhaviĝis el <strong>alia servilo</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Publike kunhavita dosiero aŭ dosierujo <strong>elŝutiĝis</strong>",
    "You received a new remote share %2$s from %1$s" : "Vi ricevis novan foran kunhavon %2$s de %1$s",
    "You received a new remote share from %s" : "Vi ricevis novan foran kunhavon de %s",
    "%1$s accepted remote share %2$s" : "%1$s akceptis foran kunhavon %2$s",
    "%1$s declined remote share %2$s" : "%1$s malakceptis foran kunhavon %2$s",
    "%1$s unshared %2$s from you" : "%1$s malkunhavigis %2$s el vi",
    "Public shared folder %1$s was downloaded" : "La publika kunhavata dosierujo %1$s elŝutiĝis",
    "Public shared file %1$s was downloaded" : "La publika kunhavata dosiero %1$s elŝutiĝis",
    "You shared %1$s with %2$s" : "Vi kunhavigis %1$s kun %2$s",
    "You removed the share of %2$s for %1$s" : "Vi malkunhavigis %1$s kun %2$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s malkunhavigis %1$s kun %3$s",
    "You shared %1$s with group %2$s" : "Vi kunhavigis %1$s kun la grupo %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s kunhavigis %1$s kun grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Vi malkunhavigis %1$s kun grupo %2$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s malkunhavigis %1$s kun grupo %3$s",
    "%2$s shared %1$s via link" : "%2$s kunhavigis %1$s ligile",
    "You shared %1$s via link" : "Vi kunhavigis %1$s per ligilo",
    "You removed the public link for %1$s" : "Vi forigis la publikan ligilon por %1$s",
    "%2$s shared %1$s with you" : "%2$s kunhavigis %1$s kun vi",
    "%2$s removed the share for %1$s" : "%2$s forigis la kunhavon kun %1$s",
    "Downloaded via public link" : "Elŝutita per publika ligilo",
    "Shared with %2$s" : "Kunhavata kun %2$s",
    "Shared with %3$s by %2$s" : "Kunhavata kun %3$s de %2$s",
    "Removed share for %2$s" : "Foriĝis kunhavo kun %2$s",
    "%2$s removed share for %3$s" : "%2$s forigis kunhavon kun %3$s",
    "Shared with group %2$s" : "Kunhavata kun grupo %2$s",
    "Shared with group %3$s by %2$s" : "Kunhavata kun grupo %3$s de %2$s",
    "Removed share of group %2$s" : "Foriĝis kunhavo kun grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s forigis kunhavon kun grupo %3$s",
    "Shared via link by %2$s" : "Kunhavata ligile de %2$s",
    "Shared via public link" : "Kunhavata publikligile",
    "Removed public link" : "Foriĝis publika ligilo",
    "%2$s removed public link" : "%2$s forigis publikan ligilon",
    "Shared by %2$s" : "Kunhavigata de %2$s",
    "Shares" : "Kunhavoj",
    "This share is password-protected" : "Ĉi tiu kunhavigo estas protektata per pasvorto",
    "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
    "Password" : "Pasvorto",
    "No entries found in this folder" : "Neniu enigo troviĝis en ĉi tiu dosierujo",
    "Name" : "Nomo",
    "Share time" : "Kunhavotempo",
    "Expiration date" : "Limdato",
    "Sorry, this link doesn’t seem to work anymore." : "Pardonu, ĉi tiu ligilo ŝajne ne plu funkcias.",
    "Reasons might be:" : "Kialoj povas esti:",
    "the item was removed" : "la ero foriĝis",
    "the link expired" : "la ligilo eksvalidiĝis",
    "sharing is disabled" : "kunhavigo malkapablas",
    "For more info, please ask the person who sent this link." : "Por plia informo, bonvolu peti al la persono, kiu sendis ĉi tiun ligilon.",
    "Add to your ownCloud" : "Aldoni al via ownCloud",
    "Download" : "Elŝuti",
    "Download %s" : "Elŝuti %s",
    "Direct link" : "Direkta ligilo"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/eo.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Interservila kunhavo ne kapabliĝis en ĉi tiu servilo",
    "Not allowed to create a federated share with the same user server" : "Ne kreeblas federa kunhavo per la sama uzantoservilo",
    "Invalid or untrusted SSL certificate" : "SSL-atestilo ne validas aŭ ne fidindas",
    "Storage not valid" : "Memoro ne validas",
    "Couldn't add remote share" : "Ne aldoneblas fora kunhavo",
    "Shared with you" : "Kunhavata kun vi",
    "Shared with others" : "Kunhavata kun aliaj",
    "Shared by link" : "Kunhavata per ligilo",
    "Uploading..." : "Alŝutante...",
    "Nothing shared with you yet" : "Nenio kunhavatas kun vi ankoraŭ",
    "Files and folders others share with you will show up here" : "Dosieroj kaj dosierujoj, kiujn aliuloj kunhavigas, aperos ĉi tie",
    "Nothing shared yet" : "Nenio kunhavatas ankoraŭ",
    "Files and folders you share will show up here" : "Dosieroj kaj dosierujoj, kiujn vi kunhavigas, aperos ĉi tie",
    "No shared links" : "Neniu kunhavata ligilo",
    "Files and folders you share by link will show up here" : "Dosieroj kaj dosierujoj, kiujn vi kunhavigas per ligilo, aperos ĉi tie",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ĉu vi volas aldoni la foran kunhavon {name} de {owner}@{remote}?",
    "Remote share" : "Fora kunhavo",
    "Remote share password" : "Pasvorto de fora kunhavo",
    "Cancel" : "Nuligi",
    "Add remote share" : "Aldoni foran kunhavon",
    "You can upload into this folder" : "Vi povas alŝuti en ĉi tiun dosierujon",
    "No ownCloud installation (7 or higher) found at {remote}" : "Ne troviĝis instalo de ownCloud (7 aŭ pli alta) ĉe {remote}",
    "Invalid ownCloud url" : "Nevalidas URL de ownCloud",
    "Share" : "Kunhavigi",
    "Shared by" : "Kunhavigita de",
    "Sharing" : "Kunhavigo",
    "A file or folder has been <strong>shared</strong>" : "Dosiero aŭ dosierujo <strong>kunhaviĝis</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Dosiero aŭ dosierujo kunhaviĝis el <strong>alia servilo</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Publike kunhavita dosiero aŭ dosierujo <strong>elŝutiĝis</strong>",
    "You received a new remote share %2$s from %1$s" : "Vi ricevis novan foran kunhavon %2$s de %1$s",
    "You received a new remote share from %s" : "Vi ricevis novan foran kunhavon de %s",
    "%1$s accepted remote share %2$s" : "%1$s akceptis foran kunhavon %2$s",
    "%1$s declined remote share %2$s" : "%1$s malakceptis foran kunhavon %2$s",
    "%1$s unshared %2$s from you" : "%1$s malkunhavigis %2$s el vi",
    "Public shared folder %1$s was downloaded" : "La publika kunhavata dosierujo %1$s elŝutiĝis",
    "Public shared file %1$s was downloaded" : "La publika kunhavata dosiero %1$s elŝutiĝis",
    "You shared %1$s with %2$s" : "Vi kunhavigis %1$s kun %2$s",
    "You removed the share of %2$s for %1$s" : "Vi malkunhavigis %1$s kun %2$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s malkunhavigis %1$s kun %3$s",
    "You shared %1$s with group %2$s" : "Vi kunhavigis %1$s kun la grupo %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s kunhavigis %1$s kun grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Vi malkunhavigis %1$s kun grupo %2$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s malkunhavigis %1$s kun grupo %3$s",
    "%2$s shared %1$s via link" : "%2$s kunhavigis %1$s ligile",
    "You shared %1$s via link" : "Vi kunhavigis %1$s per ligilo",
    "You removed the public link for %1$s" : "Vi forigis la publikan ligilon por %1$s",
    "%2$s shared %1$s with you" : "%2$s kunhavigis %1$s kun vi",
    "%2$s removed the share for %1$s" : "%2$s forigis la kunhavon kun %1$s",
    "Downloaded via public link" : "Elŝutita per publika ligilo",
    "Shared with %2$s" : "Kunhavata kun %2$s",
    "Shared with %3$s by %2$s" : "Kunhavata kun %3$s de %2$s",
    "Removed share for %2$s" : "Foriĝis kunhavo kun %2$s",
    "%2$s removed share for %3$s" : "%2$s forigis kunhavon kun %3$s",
    "Shared with group %2$s" : "Kunhavata kun grupo %2$s",
    "Shared with group %3$s by %2$s" : "Kunhavata kun grupo %3$s de %2$s",
    "Removed share of group %2$s" : "Foriĝis kunhavo kun grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s forigis kunhavon kun grupo %3$s",
    "Shared via link by %2$s" : "Kunhavata ligile de %2$s",
    "Shared via public link" : "Kunhavata publikligile",
    "Removed public link" : "Foriĝis publika ligilo",
    "%2$s removed public link" : "%2$s forigis publikan ligilon",
    "Shared by %2$s" : "Kunhavigata de %2$s",
    "Shares" : "Kunhavoj",
    "This share is password-protected" : "Ĉi tiu kunhavigo estas protektata per pasvorto",
    "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
    "Password" : "Pasvorto",
    "No entries found in this folder" : "Neniu enigo troviĝis en ĉi tiu dosierujo",
    "Name" : "Nomo",
    "Share time" : "Kunhavotempo",
    "Expiration date" : "Limdato",
    "Sorry, this link doesn’t seem to work anymore." : "Pardonu, ĉi tiu ligilo ŝajne ne plu funkcias.",
    "Reasons might be:" : "Kialoj povas esti:",
    "the item was removed" : "la ero foriĝis",
    "the link expired" : "la ligilo eksvalidiĝis",
    "sharing is disabled" : "kunhavigo malkapablas",
    "For more info, please ask the person who sent this link." : "Por plia informo, bonvolu peti al la persono, kiu sendis ĉi tiun ligilon.",
    "Add to your ownCloud" : "Aldoni al via ownCloud",
    "Download" : "Elŝuti",
    "Download %s" : "Elŝuti %s",
    "Direct link" : "Direkta ligilo",
    "Pending" : "Traktotaj",
    "Accept" : "Akcepti",
    "Decline" : "Malakcepti",
    "Declined" : "Malakceptita"
},
"nplurals=2; plural=(n != 1);");
